###############################################################################
#
# Tests for libxlsxwriter.
#
# Copyright 2014-2022, John McNamara, jmcnamara@cpan.org
#

import os
import pytest
import base_test_class

class TestCompareXLSXFiles(base_test_class.XLSXBaseTest):
    """
    Test file created with libxlsxwriter against a file created by Excel.

    """
    def test_image01(self):
        self.run_exe_test('test_image01')

    def test_image02(self):
        self.run_exe_test('test_image02')

    def test_image03(self):
        self.run_exe_test('test_image03')

    def test_image04(self):
        self.run_exe_test('test_image04')

    def test_image05(self):
        self.run_exe_test('test_image05')

    def test_image07(self):
        self.run_exe_test('test_image07')

    def test_image08(self):
        self.run_exe_test('test_image08')

    def test_image09(self):
        self.run_exe_test('test_image09')

    def test_image10(self):
        self.run_exe_test('test_image10')

    def test_image11(self):
        self.run_exe_test('test_image11')

    def test_image12(self):
        self.run_exe_test('test_image12')

    def test_image13(self):
        self.run_exe_test('test_image13')

    def test_image14(self):
        self.run_exe_test('test_image14')

    def test_image15(self):
        self.run_exe_test('test_image15')

    def test_image16(self):
        self.run_exe_test('test_image16')

    def test_image17(self):
        self.run_exe_test('test_image17')

    def test_image18(self):
        self.run_exe_test('test_image18')

    def test_image19(self):
        self.run_exe_test('test_image19')

    def test_image22(self):
        self.run_exe_test('test_image22')

    def test_image23(self):
        self.run_exe_test('test_image23')

    def test_image24(self):
        self.run_exe_test('test_image24')

    def test_image25(self):
        self.run_exe_test('test_image25')

    def test_image26(self):
        self.run_exe_test('test_image26')

    def test_image27(self):
        self.run_exe_test('test_image27')

    def test_image28(self):
        self.run_exe_test('test_image28')

    def test_image29(self):
        self.run_exe_test('test_image29')

    def test_image30(self):
        self.run_exe_test('test_image30')

    def test_image31(self):
        self.run_exe_test('test_image31')

    def test_image32(self):
        self.run_exe_test('test_image32')

    def test_image33(self):
        self.run_exe_test('test_image33')

    def test_image34(self):
        self.run_exe_test('test_image34')

    def test_image35(self):
        self.run_exe_test('test_image35')

    def test_image36(self):
        self.run_exe_test('test_image36')

    def test_image44(self):
        self.run_exe_test('test_image44')

    def test_image45(self):
        self.run_exe_test('test_image45')

    def test_image46(self):
        self.run_exe_test('test_image46')

    def test_image47(self):
        self.run_exe_test('test_image47')

    # Some of the following tests require MD5 hash support to remove duplicate images.
    @pytest.mark.skipif(os.environ.get('USE_NO_MD5'), reason="compiled without MD5 support")
    def test_image48(self):
        self.run_exe_test('test_image48')

    @pytest.mark.skipif(os.environ.get('USE_NO_MD5'), reason="compiled without MD5 support")
    def test_image49(self):
        self.run_exe_test('test_image49')

    @pytest.mark.skipif(os.environ.get('USE_NO_MD5'), reason="compiled without MD5 support")
    def test_image50(self):
        self.run_exe_test('test_image50')

    @pytest.mark.skipif(os.environ.get('USE_NO_MD5'), reason="compiled without MD5 support")
    def test_image51(self):
        self.run_exe_test('test_image51')

    def test_image52(self):
        self.run_exe_test('test_image52')

    def test_image53(self):
        self.run_exe_test('test_image53')

    def test_image54(self):
        self.run_exe_test('test_image54')

    def test_image55(self):
        self.run_exe_test('test_image55')

    def test_image56(self):
        self.run_exe_test('test_image56')

    def test_image57(self):
        self.run_exe_test('test_image57')

    # Test in-memory image handling.
    def test_image81(self):
        self.run_exe_test('test_image81', 'image01.xlsx')

    def test_image82(self):
        self.run_exe_test('test_image82')

    def test_image83(self):
        self.run_exe_test('test_image83', 'image02.xlsx')

    def test_image89(self):
        self.run_exe_test('test_image89', 'image03.xlsx')

    @pytest.mark.skipif(os.environ.get('USE_NO_MD5'), reason="compiled without MD5 support")
    def test_image86(self):
        self.run_exe_test('test_image86', 'image48.xlsx')

    @pytest.mark.skipif(os.environ.get('USE_NO_MD5'), reason="compiled without MD5 support")
    def test_image87(self):
        self.run_exe_test('test_image87', 'image50.xlsx')

    @pytest.mark.skipif(os.environ.get('USE_NO_MD5'), reason="compiled without MD5 support")
    def test_image88(self):
        self.run_exe_test('test_image88', 'image54.xlsx')

    # Test image description fields.
    def test_image84(self):
        self.run_exe_test('test_image84')

    def test_image85(self):
        self.run_exe_test('test_image85')



###############################################################################
#
# Tests for libxlsxwriter.
#
# Copyright 2014-2022, John McNamara, jmcnamara@cpan.org
#

import base_test_class

class TestCompareXLSXFiles(base_test_class.XLSXBaseTest):
    """
    Test file created with libxlsxwriter against a file created by Excel.

    """

    def test_table01(self):
        self.run_exe_test('test_table01')

    def test_table02(self):
        self.run_exe_test('test_table02')

    def test_table03(self):
        self.run_exe_test('test_table03')

    def test_table04(self):
        self.run_exe_test('test_table04')

    def test_table05(self):
        self.run_exe_test('test_table05')

    def test_table06(self):
        self.run_exe_test('test_table06')

    def test_table07(self):
        self.run_exe_test('test_table07')

    def test_table08(self):
        self.ignore_files = ['xl/calcChain.xml',
                             '[Content_Types].xml',
                             'xl/_rels/workbook.xml.rels']
        self.run_exe_test('test_table08')

    def test_table09(self):
        self.ignore_files = ['xl/calcChain.xml',
                             '[Content_Types].xml',
                             'xl/_rels/workbook.xml.rels']
        self.run_exe_test('test_table09')

    def test_table10(self):
        self.ignore_files = ['xl/calcChain.xml',
                             '[Content_Types].xml',
                             'xl/_rels/workbook.xml.rels']
        self.run_exe_test('test_table10')

    def test_table11(self):
        self.run_exe_test('test_table11')

    def test_table12(self):
        self.run_exe_test('test_table12')

    # Skip test_table13 since we can't set the dxf index for
    # format_set_num_format_index() formats with C hash struct.

    def test_table14(self):
        self.run_exe_test('test_table14')

    def test_table15(self):
        self.run_exe_test('test_table15')

    def test_table16(self):
        self.run_exe_test('test_table16', 'table02.xlsx')

    def test_table17(self):
        self.ignore_files = ['xl/calcChain.xml',
                             '[Content_Types].xml',
                             'xl/_rels/workbook.xml.rels']
        self.run_exe_test('test_table17')

    def test_table18(self):
        self.run_exe_test('test_table18')

    def test_table19(self):
        self.run_exe_test('test_table19')

    # TODO. Duplicate names.

    def test_table21(self):
        self.run_exe_test('test_table21')

    def test_table22(self):
        self.run_exe_test('test_table22')

    def test_table23(self):
        self.ignore_files = ['xl/calcChain.xml',
                             '[Content_Types].xml',
                             'xl/_rels/workbook.xml.rels']
        self.run_exe_test('test_table23')

    def test_table24(self):
        self.run_exe_test('test_table24')

    def test_table25(self):
        self.run_exe_test('test_table25')

    def test_table26(self):
        self.run_exe_test('test_table26')



###############################################################################
#
# Tests for libxlsxwriter.
#
# Copyright 2014-2022, John McNamara, jmcnamara@cpan.org
#

import base_test_class

class TestCompareXLSXFiles(base_test_class.XLSXBaseTest):
    """
    Test file created with libxlsxwriter against a file created by Excel.

    """

    def test_chart_format01(self):
        self.run_exe_test('test_chart_format01')

    def test_chart_format02(self):
        self.run_exe_test('test_chart_format02')

    def test_chart_format03(self):
        self.run_exe_test('test_chart_format03')

    def test_chart_format04(self):
        self.run_exe_test('test_chart_format04')

    def test_chart_format05(self):
        self.run_exe_test('test_chart_format05')

    def test_chart_format06(self):
        self.run_exe_test('test_chart_format06')

    def test_chart_format07(self):
        self.run_exe_test('test_chart_format07')

    def test_chart_format08(self):
        self.run_exe_test('test_chart_format08')

    def test_chart_format09(self):
        self.run_exe_test('test_chart_format09')

    def test_chart_format10(self):
        self.run_exe_test('test_chart_format10')

    def test_chart_format11(self):
        self.run_exe_test('test_chart_format11')

    def test_chart_format12(self):
        self.run_exe_test('test_chart_format12')

    def test_chart_format13(self):
        self.run_exe_test('test_chart_format13')

    def test_chart_format14(self):
        self.run_exe_test('test_chart_format14')

    def test_chart_format14(self):
        self.run_exe_test('test_chart_format14')

    def test_chart_format15(self):
        self.run_exe_test('test_chart_format15')

    def test_chart_format16(self):
        self.run_exe_test('test_chart_format16')

    def test_chart_format17(self):
        self.run_exe_test('test_chart_format17')

    def test_chart_format18(self):
        self.run_exe_test('test_chart_format18')

    def test_chart_format19(self):
        self.run_exe_test('test_chart_format19')

    def test_chart_format20(self):
        self.run_exe_test('test_chart_format20')

    def test_chart_format21(self):
        self.run_exe_test('test_chart_format21')

    def test_chart_format22(self):
        self.run_exe_test('test_chart_format22')

    def test_chart_format23(self):
        self.run_exe_test('test_chart_format23')

    def test_chart_format24(self):
        self.run_exe_test('test_chart_format24')

    def test_chart_format25(self):
        self.run_exe_test('test_chart_format25')

    def test_chart_format26(self):
        self.run_exe_test('test_chart_format26')

    def test_chart_format27(self):
        self.run_exe_test('test_chart_format27')

    def test_chart_format28(self):
        self.run_exe_test('test_chart_format28')

    def test_chart_format29(self):
        self.run_exe_test('test_chart_format29')

    def test_chart_format30(self):
        self.run_exe_test('test_chart_format30')

    def test_chart_format31(self):
        self.run_exe_test('test_chart_format31')



###############################################################################
#
# Tests for libxlsxwriter.
#
# Copyright 2014-2022, John McNamara, jmcnamara@cpan.org
#

import base_test_class

class TestCompareXLSXFiles(base_test_class.XLSXBaseTest):
    """
    Test file created with libxlsxwriter against a file created by Excel.

    """

    # def test_escapes01(self):
    #     self.run_exe_test('test_escapes01')

    # def test_escapes02(self):
    #     self.run_exe_test('test_escapes02')

    def test_escapes03(self):
        self.run_exe_test('test_escapes03')

    def test_escapes04(self):
        self.run_exe_test('test_escapes04')

    def test_escapes05(self):
        self.run_exe_test('test_escapes05')

    def test_escapes06(self):
        self.run_exe_test('test_escapes06')

    def test_escapes07(self):
        self.run_exe_test('test_escapes07')

    def test_escapes08(self):
        self.run_exe_test('test_escapes08')



###############################################################################
#
# Tests for libxlsxwriter.
#
# Copyright 2014-2022, John McNamara, jmcnamara@cpan.org
#

import base_test_class

class TestCompareXLSXFiles(base_test_class.XLSXBaseTest):
    """
    Test file created with libxlsxwriter against a file created by Excel.

    """

    def test_chart_crossing01(self):
        self.run_exe_test('test_chart_crossing01')

    def test_chart_crossing02(self):
        self.run_exe_test('test_chart_crossing02')

    def test_chart_crossing03(self):
        self.run_exe_test('test_chart_crossing03')

    def test_chart_crossing04(self):
        self.run_exe_test('test_chart_crossing04')

    def test_chart_crossing05(self):
        self.run_exe_test('test_chart_crossing05')

    def test_chart_crossing06(self):
        self.run_exe_test('test_chart_crossing06')



###############################################################################
#
# Tests for libxlsxwriter.
#
# Copyright 2014-2022, John McNamara, jmcnamara@cpan.org
#

import base_test_class

class TestCompareXLSXFiles(base_test_class.XLSXBaseTest):
    """
    Test file created with libxlsxwriter against a file created by Excel.

    """

    def test_repeat01(self):
        self.ignore_elements = {'xl/worksheets/sheet1.xml': ['<pageMargins']}
        self.run_exe_test('test_repeat01')

    def test_repeat02(self):
        self.ignore_elements = {'xl/worksheets/sheet1.xml': ['<pageMargins']}
        self.run_exe_test('test_repeat02')

    def test_repeat03(self):
        self.ignore_elements = {'xl/worksheets/sheet1.xml': ['<pageMargins']}
        self.run_exe_test('test_repeat03')

    def test_repeat04(self):
        self.ignore_elements = {'xl/worksheets/sheet1.xml': ['<pageMargins']}
        self.run_exe_test('test_repeat04')

    def test_repeat05(self):
        self.ignore_files = ['docProps/app.xml']
        self.ignore_elements = {'xl/worksheets/sheet1.xml': ['<pageMargins'],
                                'xl/worksheets/sheet3.xml': ['<pageMargins']}
        self.run_exe_test('test_repeat05')

    def test_repeat06(self):
        self.ignore_elements = {'xl/worksheets/sheet1.xml': ['<pageMargins']}
        self.run_exe_test('test_repeat06')



###############################################################################
#
# Tests for libxlsxwriter.
#
# Copyright 2014-2022, John McNamara, jmcnamara@cpan.org
#

import base_test_class

class TestCompareXLSXFiles(base_test_class.XLSXBaseTest):
    """
    Test file created with libxlsxwriter against a file created by Excel.

    """

    def test_array_formula01(self):
        self.ignore_files = ['xl/calcChain.xml',
                             '[Content_Types].xml',
                             'xl/_rels/workbook.xml.rels']
        self.run_exe_test('test_array_formula01')

    def test_array_formula02(self):
        self.ignore_files = ['xl/calcChain.xml',
                             '[Content_Types].xml',
                             'xl/_rels/workbook.xml.rels']
        self.run_exe_test('test_array_formula02')

    def test_array_formula03(self):
        self.ignore_files = ['xl/calcChain.xml',
                             '[Content_Types].xml',
                             'xl/_rels/workbook.xml.rels']
        self.run_exe_test('test_array_formula03')

    def test_array_formula04(self):
        self.ignore_files = ['xl/calcChain.xml',
                             '[Content_Types].xml',
                             'xl/_rels/workbook.xml.rels']
        self.run_exe_test('test_array_formula04')




###############################################################################
#
# Tests for libxlsxwriter.
#
# Copyright 2014-2022, John McNamara, jmcnamara@cpan.org
#

import base_test_class

class TestCompareXLSXFiles(base_test_class.XLSXBaseTest):
    """
    Test writing a workbook in optimization/constant memory mode.

    """

    def test_optimize01(self):
        self.run_exe_test('test_optimize01')

    def test_optimize02(self):
        self.run_exe_test('test_optimize02')

    def test_optimize04(self):
        self.run_exe_test('test_optimize04')

    def test_optimize05(self):
        self.run_exe_test('test_optimize05')

    def test_optimize06(self):
        self.run_exe_test('test_optimize06')

    def test_optimize08(self):
        self.run_exe_test('test_optimize08')

    # Skip some of the XlsxWriter tests until the required functionality is ported.

    def test_optimize13(self):
        self.run_exe_test('test_optimize13')

    def test_optimize14(self):
        self.run_exe_test('test_optimize14')

    def test_optimize21(self):
        self.run_exe_test('test_optimize21')

    def test_optimize22(self):
        self.run_exe_test('test_optimize22')

    def test_optimize23(self):
        self.run_exe_test('test_optimize23')

    def test_optimize24(self):
        self.run_exe_test('test_optimize24')

    def test_optimize25(self):
        self.run_exe_test('test_optimize25')

    def test_optimize26(self):
        self.run_exe_test('test_optimize26')



###############################################################################
#
# Tests for libxlsxwriter.
#
# Copyright 2014-2022, John McNamara, jmcnamara@cpan.org
#

import os
import pytest
import base_test_class

class TestCompareXLSXFiles(base_test_class.XLSXBaseTest):
    """
    Test file created with libxlsxwriter against a file created by Excel.

    """

    def test_header_image01(self):
        self.ignore_elements = {'xl/worksheets/sheet1.xml': ['<pageMargins', '<pageSetup']}
        self.run_exe_test('test_header_image01')

    def test_header_image02(self):
        self.ignore_elements = {'xl/worksheets/sheet1.xml': ['<pageMargins', '<pageSetup']}
        self.run_exe_test('test_header_image02')

    def test_header_image03(self):
        self.ignore_elements = {'xl/worksheets/sheet1.xml': ['<pageMargins', '<pageSetup']}
        self.run_exe_test('test_header_image03')

    def test_header_image04(self):
        self.ignore_elements = {'xl/worksheets/sheet1.xml': ['<pageMargins', '<pageSetup']}
        self.run_exe_test('test_header_image04')

    def test_header_image05(self):
        self.ignore_elements = {'xl/worksheets/sheet1.xml': ['<pageMargins', '<pageSetup']}
        self.run_exe_test('test_header_image05')

    def test_header_image06(self):
        self.ignore_elements = {'xl/worksheets/sheet1.xml': ['<pageMargins', '<pageSetup'],
                                'xl/worksheets/sheet2.xml': ['<pageMargins', '<pageSetup']}
        self.run_exe_test('test_header_image06')

    def test_header_image07(self):
        self.ignore_elements = {'xl/worksheets/sheet1.xml': ['<pageMargins', '<pageSetup']}
        self.run_exe_test('test_header_image07')

    def test_header_image08(self):
        self.ignore_elements = {'xl/worksheets/sheet1.xml': ['<pageMargins', '<pageSetup']}
        self.run_exe_test('test_header_image08')

    def test_header_image09(self):
        self.ignore_elements = {'xl/worksheets/sheet1.xml': ['<pageMargins', '<pageSetup'],
                                'xl/worksheets/sheet2.xml': ['<pageMargins', '<pageSetup']}
        self.run_exe_test('test_header_image09')

    def test_header_image10(self):
        self.ignore_elements = {'xl/worksheets/sheet1.xml': ['<pageMargins', '<pageSetup'],
                                'xl/worksheets/sheet2.xml': ['<pageMargins', '<pageSetup']}
        self.run_exe_test('test_header_image10')

    def test_header_image11(self):
        self.ignore_elements = {'xl/worksheets/sheet1.xml': ['<pageMargins', '<pageSetup']}
        self.run_exe_test('test_header_image11')

    def test_header_image12(self):
        self.ignore_elements = {'xl/worksheets/sheet1.xml': ['<pageMargins', '<pageSetup']}
        self.run_exe_test('test_header_image12')

    def test_header_image13(self):
        self.ignore_elements = {'xl/worksheets/sheet1.xml': ['<pageMargins', '<pageSetup']}
        self.run_exe_test('test_header_image13')

    def test_header_image14(self):
        self.ignore_elements = {'xl/worksheets/sheet1.xml': ['<pageMargins', '<pageSetup']}
        self.run_exe_test('test_header_image14')

    @pytest.mark.skipif(os.environ.get('USE_NO_MD5'), reason="compiled without MD5 support")
    def test_header_image15(self):
        self.ignore_elements = {'xl/worksheets/sheet1.xml': ['<pageMargins', '<pageSetup'],
                                'xl/worksheets/sheet2.xml': ['<pageMargins', '<pageSetup']}
        self.run_exe_test('test_header_image15')

    @pytest.mark.skipif(os.environ.get('USE_NO_MD5'), reason="compiled without MD5 support")
    def test_header_image16(self):
        self.ignore_elements = {'xl/worksheets/sheet1.xml': ['<pageMargins', '<pageSetup'],
                                'xl/worksheets/sheet2.xml': ['<pageMargins', '<pageSetup']}
        self.run_exe_test('test_header_image16')

    @pytest.mark.skipif(os.environ.get('USE_NO_MD5'), reason="compiled without MD5 support")
    def test_header_image17(self):
        self.ignore_elements = {'xl/worksheets/sheet1.xml': ['<pageMargins', '<pageSetup']}
        self.run_exe_test('test_header_image17')

    @pytest.mark.skipif(os.environ.get('USE_NO_MD5'), reason="compiled without MD5 support")
    def test_header_image18(self):
        self.ignore_elements = {'xl/worksheets/sheet1.xml': ['<pageMargins', '<pageSetup']}
        self.run_exe_test('test_header_image18')

    def test_header_image19(self):
        self.ignore_elements = {'xl/worksheets/sheet1.xml': ['<pageMargins', '<pageSetup']}
        self.run_exe_test('test_header_image19')

    def test_header_image20(self):
        self.ignore_elements = {'xl/worksheets/sheet1.xml': ['<pageMargins', '<pageSetup']}
        self.run_exe_test('test_header_image20')
                          
    # Test format strings with &[Picture] instead of &G.
    def test_header_image51(self):
        self.ignore_elements = {'xl/worksheets/sheet1.xml': ['<pageMargins', '<pageSetup']}
        self.run_exe_test('test_header_image51', 'header_image01.xlsx')

    def test_header_image52(self):
        self.ignore_elements = {'xl/worksheets/sheet1.xml': ['<pageMargins', '<pageSetup']}
        self.run_exe_test('test_header_image52', 'header_image02.xlsx')

    def test_header_image53(self):
        self.ignore_elements = {'xl/worksheets/sheet1.xml': ['<pageMargins', '<pageSetup']}
        self.run_exe_test('test_header_image53', 'header_image03.xlsx')

    # Manually modified version of test_header_image05 so margins can be compared.
    def test_header_image55(self):
        self.run_exe_test('test_header_image55')



###############################################################################
#
# Tests for libxlsxwriter.
#
# Copyright 2014-2022, John McNamara, jmcnamara@cpan.org
#

import base_test_class

class TestCompareXLSXFiles(base_test_class.XLSXBaseTest):
    """
    Test file created with libxlsxwriter against a file created by Excel.

    """

    def test_chartsheet01(self):
        self.run_exe_test('test_chartsheet01')

    def test_chartsheet02(self):
        self.run_exe_test('test_chartsheet02')

    def test_chartsheet03(self):
        self.run_exe_test('test_chartsheet03')

    def test_chartsheet04(self):
        self.run_exe_test('test_chartsheet04')

    def test_chartsheet05(self):
        self.run_exe_test('test_chartsheet05')

    def test_chartsheet06(self):
        self.run_exe_test('test_chartsheet06')

    def test_chartsheet07(self):
        self.run_exe_test('test_chartsheet07')

    def test_chartsheet08(self):
        self.ignore_files = ['xl/drawings/drawing1.xml']
        self.run_exe_test('test_chartsheet08')

    def test_chartsheet09(self):
        self.run_exe_test('test_chartsheet09')



###############################################################################
#
# Base test class for libxlsxwriter functional tests.
#
# Copyright 2014-2022, John McNamara, jmcnamara@cpan.org
#

import unittest
import os
import sys
from helper_functions import _compare_xlsx_files


class XLSXBaseTest(unittest.TestCase):
    """
    Test file created with libxlsxwriter against a file created by Excel.

    """

    def setUp(self):
        self.maxDiff = None

        self.no_system_error = 0
        self.got_filename = ''
        self.exp_filename = ''
        self.ignore_files = []
        self.ignore_elements = {}

    def run_exe_test(self, exe_name, exp_filename=None):
        """Run C exe and compare output xlsx file with the Excel file."""

        # Create the executable command
        if sys.platform == 'win32':
            command = r'cd test\functional\src && %s.exe' % exe_name
        else:
            command = 'cd test/functional/src && ./%s' % exe_name

        # Run the C executable to generate the "got" xlsx file.
        got = os.system(command)
        self.assertEqual(got, self.no_system_error)

        # Create the path/file names for the xlsx/xlsm files to compare.
        if exp_filename and exp_filename.endswith('.xlsm'):
            got_filename = exe_name.replace('test_', '') + '.xlsm'
        else:
            got_filename = exe_name.replace('test_', '') + '.xlsx'

        if not exp_filename:
            exp_filename = got_filename

        self.got_filename = 'test/functional/src/test_' + got_filename
        self.exp_filename = 'test/functional/xlsx_files/' + exp_filename

        # Do the comparison between the files.
        got, exp = _compare_xlsx_files(self.got_filename,
                                       self.exp_filename,
                                       self.ignore_files,
                                       self.ignore_elements)
        self.assertEqual(exp, got)

    def tearDown(self):
        # Cleanup.
        if os.path.exists(self.got_filename):
            os.remove(self.got_filename)

        self.ignore_files = []
        self.ignore_elements = {}



###############################################################################
#
# Tests for libxlsxwriter.
#
# Copyright 2014-2022, John McNamara, jmcnamara@cpan.org
#

import base_test_class

class TestCompareXLSXFiles(base_test_class.XLSXBaseTest):
    """
    Test file created with libxlsxwriter against a file created by Excel.

    """

    def test_fit_to_pages01(self):
        self.ignore_elements = {'xl/worksheets/sheet1.xml': ['<pageMargins']}
        self.run_exe_test('test_fit_to_pages01')

    def test_fit_to_pages02(self):
        self.ignore_elements = {'xl/worksheets/sheet1.xml': ['<pageMargins']}
        self.run_exe_test('test_fit_to_pages02')

    def test_fit_to_pages03(self):
        self.ignore_elements = {'xl/worksheets/sheet1.xml': ['<pageMargins']}
        self.run_exe_test('test_fit_to_pages03')

    def test_fit_to_pages04(self):
        self.ignore_elements = {'xl/worksheets/sheet1.xml': ['<pageMargins']}
        self.run_exe_test('test_fit_to_pages04')

    def test_fit_to_pages05(self):
        self.ignore_elements = {'xl/worksheets/sheet1.xml': ['<pageMargins']}
        self.run_exe_test('test_fit_to_pages05')



###############################################################################
#
# Tests for libxlsxwriter.
#
# Copyright 2014-2022, John McNamara, jmcnamara@cpan.org
#

import base_test_class

class TestCompareXLSXFiles(base_test_class.XLSXBaseTest):
    """
    Test file created with libxlsxwriter against a file created by Excel.

    """

    def test_chart_blank01(self):
        self.run_exe_test('test_chart_blank01')

    def test_chart_blank02(self):
        self.run_exe_test('test_chart_blank02')

    def test_chart_blank03(self):
        self.run_exe_test('test_chart_blank03')

    def test_chart_blank04(self):
        self.run_exe_test('test_chart_blank04')

    def test_chart_blank05(self):
        self.ignore_elements = {'xl/drawings/drawing1.xml': ['<xdr:ext']}
        self.run_exe_test('test_chart_blank05')

    def test_chart_blank06(self):
        self.run_exe_test('test_chart_blank06')



###############################################################################
#
# Tests for libxlsxwriter.
#
# Copyright 2014-2022, John McNamara, jmcnamara@cpan.org
#

import base_test_class

class TestCompareXLSXFiles(base_test_class.XLSXBaseTest):
    """
    Test file created with libxlsxwriter against a file created by Excel.

    """

    def test_chart_pattern01(self):
        self.run_exe_test('test_chart_pattern01')

    def test_chart_pattern02(self):
        self.run_exe_test('test_chart_pattern02')

    def test_chart_pattern03(self):
        self.run_exe_test('test_chart_pattern03')

    def test_chart_pattern04(self):
        self.run_exe_test('test_chart_pattern04')

    def test_chart_pattern05(self):
        self.run_exe_test('test_chart_pattern05')

    def test_chart_pattern06(self):
        self.run_exe_test('test_chart_pattern06')

    def test_chart_pattern07(self):
        self.run_exe_test('test_chart_pattern07')

    def test_chart_pattern08(self):
        self.run_exe_test('test_chart_pattern08')

    def test_chart_pattern10(self):
        self.run_exe_test('test_chart_pattern10')



###############################################################################
#
# Tests for libxlsxwriter.
#
# Copyright 2014-2022, John McNamara, jmcnamara@cpan.org
#

import base_test_class

class TestCompareXLSXFiles(base_test_class.XLSXBaseTest):
    """
    Test file created with libxlsxwriter against a file created by Excel.

    """

    def test_chart_display_units01(self):
        self.run_exe_test('test_chart_display_units01')

    def test_chart_display_units02(self):
        self.run_exe_test('test_chart_display_units02')

    def test_chart_display_units03(self):
        self.run_exe_test('test_chart_display_units03')

    def test_chart_display_units04(self):
        self.run_exe_test('test_chart_display_units04')

    def test_chart_display_units05(self):
        self.run_exe_test('test_chart_display_units05')

    def test_chart_display_units06(self):
        self.run_exe_test('test_chart_display_units06')

    def test_chart_display_units07(self):
        self.run_exe_test('test_chart_display_units07')

    def test_chart_display_units08(self):
        self.run_exe_test('test_chart_display_units08')

    def test_chart_display_units09(self):
        self.run_exe_test('test_chart_display_units09')

    def test_chart_display_units10(self):
        self.run_exe_test('test_chart_display_units10')

    def test_chart_display_units11(self):
        self.run_exe_test('test_chart_display_units11')

    def test_chart_display_units12(self):
        self.run_exe_test('test_chart_display_units12')



###############################################################################
#
# Tests for libxlsxwriter.
#
# Copyright 2014-2022, John McNamara, jmcnamara@cpan.org
#

import base_test_class

class TestCompareXLSXFiles(base_test_class.XLSXBaseTest):
    """
    Test file created with libxlsxwriter against a file created by Excel.

    """

    def test_data_validation01(self):
        self.run_exe_test('test_data_validation01')

    def test_data_validation02(self):
        self.run_exe_test('test_data_validation02')

    def test_data_validation03(self):
        self.run_exe_test('test_data_validation03')

    def test_data_validation04(self):
        self.run_exe_test('test_data_validation04', 'data_validation02.xlsx')

    def test_data_validation05(self):
        self.run_exe_test('test_data_validation05', 'data_validation02.xlsx')

    def test_data_validation06(self):
        self.run_exe_test('test_data_validation06', 'data_validation02.xlsx')

    def test_data_validation07(self):
        self.run_exe_test('test_data_validation07')

    def test_data_validation08(self):
        self.run_exe_test('test_data_validation08')



###############################################################################
#
# Tests for libxlsxwriter.
#
# Copyright 2014-2022, John McNamara, jmcnamara@cpan.org
#

import base_test_class

class TestCompareXLSXFiles(base_test_class.XLSXBaseTest):
    """
    Test file created with libxlsxwriter against a file created by Excel.

    """

    def test_chart_errorbars01(self):
        self.run_exe_test('test_chart_errorbars01')

    def test_chart_errorbars02(self):
        self.run_exe_test('test_chart_errorbars02')

    def test_chart_errorbars03(self):
        self.run_exe_test('test_chart_errorbars03')

    def test_chart_errorbars04(self):
        self.run_exe_test('test_chart_errorbars04')

    def test_chart_errorbars05(self):
        self.run_exe_test('test_chart_errorbars05')

    def test_chart_errorbars06(self):
        self.run_exe_test('test_chart_errorbars06')



###############################################################################
#
# Tests for libxlsxwriter.
#
# Copyright 2014-2022, John McNamara, jmcnamara@cpan.org
#

import base_test_class

class TestCompareXLSXFiles(base_test_class.XLSXBaseTest):
    """
    Test file created with libxlsxwriter against a file created by Excel.

    """

    def test_chart_bar01(self):
        self.run_exe_test('test_chart_bar01')

    def test_chart_bar02(self):
        self.run_exe_test('test_chart_bar02')

    def test_chart_bar03(self):
        self.run_exe_test('test_chart_bar03')

    def test_chart_bar04(self):
        self.run_exe_test('test_chart_bar04')

    def test_chart_bar05(self):
        self.run_exe_test('test_chart_bar05')

    def test_chart_bar06(self):
        self.run_exe_test('test_chart_bar06')

    def test_chart_bar08(self):
        self.run_exe_test('test_chart_bar08')

    def test_chart_bar09(self):
        self.run_exe_test('test_chart_bar09')

    def test_chart_bar10(self):
        self.run_exe_test('test_chart_bar10')

    def test_chart_bar11(self):
        self.run_exe_test('test_chart_bar11')

    def test_chart_bar12(self):
        self.run_exe_test('test_chart_bar12')

    def test_chart_bar13(self):
        self.run_exe_test('test_chart_bar13')

    def test_chart_bar14(self):
        self.run_exe_test('test_chart_bar14')

    def test_chart_bar15(self):
        self.run_exe_test('test_chart_bar15')

    def test_chart_bar17(self):
        self.run_exe_test('test_chart_bar17')

    def test_chart_bar16(self):
        self.run_exe_test('test_chart_bar16')

    def test_chart_bar18(self):
        self.run_exe_test('test_chart_bar18')

    def test_chart_bar19(self):
        self.run_exe_test('test_chart_bar19')

    def test_chart_bar20(self):
        self.run_exe_test('test_chart_bar20')

    def test_chart_bar21(self):
        self.run_exe_test('test_chart_bar21')

    def test_chart_bar22(self):
        self.run_exe_test('test_chart_bar22')

    # 23 is a duplicate of 22 without explicit cache data.

    # Some of the following tests use the same target excel files as the tests
    # above but test variations of the interface.

    def test_chart_bar51(self):
        self.run_exe_test('test_chart_bar51')

    def test_chart_bar52(self):
        self.run_exe_test('test_chart_bar52', 'chart_bar02.xlsx')

    def test_chart_bar53(self):
        self.run_exe_test('test_chart_bar53', 'chart_bar03.xlsx')

    def test_chart_bar54(self):
        self.run_exe_test('test_chart_bar54', 'chart_bar04.xlsx')

    def test_chart_bar55(self):
        self.run_exe_test('test_chart_bar55', 'chart_bar05.xlsx')

    def test_chart_bar61(self):
        self.run_exe_test('test_chart_bar61', 'chart_bar01.xlsx')

    def test_chart_bar65(self):
        self.run_exe_test('test_chart_bar65', 'chart_bar05.xlsx')

    def test_chart_bar69(self):
        self.run_exe_test('test_chart_bar69', 'chart_bar19.xlsx')

    def test_chart_bar70(self):
        self.run_exe_test('test_chart_bar70', 'chart_bar20.xlsx')



###############################################################################
#
# Tests for libxlsxwriter.
#
# Copyright 2014-2022, John McNamara, jmcnamara@cpan.org
#

import base_test_class

class TestCompareXLSXFiles(base_test_class.XLSXBaseTest):
    """
    Test file created with libxlsxwriter against a file created by Excel.

    """

    def test_chart_scatter01(self):
        self.run_exe_test('test_chart_scatter01')

    def test_chart_scatter02(self):
        self.run_exe_test('test_chart_scatter02')

    def test_chart_scatter03(self):
        self.run_exe_test('test_chart_scatter03')

    def test_chart_scatter04(self):
        self.run_exe_test('test_chart_scatter04')

    def test_chart_scatter05(self):
        self.run_exe_test('test_chart_scatter05')

    def test_chart_scatter06(self):
        self.run_exe_test('test_chart_scatter06')

    def test_chart_scatter09(self):
        self.run_exe_test('test_chart_scatter09')

    def test_chart_scatter10(self):
        self.run_exe_test('test_chart_scatter10')

    def test_chart_scatter11(self):
        self.run_exe_test('test_chart_scatter11')

    def test_chart_scatter12(self):
        self.run_exe_test('test_chart_scatter12')

    def test_chart_scatter13(self):
        self.run_exe_test('test_chart_scatter13', 'chart_scatter12.xlsx')

    def test_chart_scatter14(self):
        self.run_exe_test('test_chart_scatter14')

    def test_chart_scatter15(self):
        self.run_exe_test('test_chart_scatter15')



###############################################################################
#
# Tests for libxlsxwriter.
#
# Copyright 2014-2022, John McNamara, jmcnamara@cpan.org
#

import base_test_class

class TestCompareXLSXFiles(base_test_class.XLSXBaseTest):
    """
    Test file created with libxlsxwriter against a file created by Excel.

    """

    def test_chart_chartarea01(self):
        self.run_exe_test('test_chart_chartarea01')

    # chartarea02 is for a deprecated api in Perl.

    def test_chart_chartarea03(self):
        self.run_exe_test('test_chart_chartarea03')

    # chartarea04 is an unsupported stock chart.

    def test_chart_chartarea05(self):
        self.run_exe_test('test_chart_chartarea05')

    def test_chart_chartarea06(self):
        self.run_exe_test('test_chart_chartarea06')



###############################################################################
#
# Tests for libxlsxwriter.
#
# Copyright 2014-2022, John McNamara, jmcnamara@cpan.org
#

import base_test_class

class TestCompareXLSXFiles(base_test_class.XLSXBaseTest):
    """
    Test file created with libxlsxwriter against a file created by Excel.

    """

    def test_data01(self):
        self.run_exe_test('test_data01')

    def test_data02(self):
        self.run_exe_test('test_data02')

    def test_data03(self):
        self.run_exe_test('test_data03')

    def test_data04(self):
        self.run_exe_test('test_data04')

    def test_data05(self):
        self.run_exe_test('test_data05')

    def test_data06(self):
        self.run_exe_test('test_data06')

    def test_data07(self):
        self.ignore_files = ['xl/calcChain.xml',
                             '[Content_Types].xml',
                             'xl/_rels/workbook.xml.rels']
        self.run_exe_test('test_data07')

    def test_data08(self):
        self.run_exe_test('test_data08', 'format06.xlsx')

    def test_data09(self):
        self.ignore_files = ['xl/calcChain.xml',
                             '[Content_Types].xml',
                             'xl/_rels/workbook.xml.rels']
        self.run_exe_test('test_data09')



###############################################################################
#
# Tests for libxlsxwriter.
#
# Copyright 2014-2022, John McNamara, jmcnamara@cpan.org
#

import base_test_class

class TestCompareXLSXFiles(base_test_class.XLSXBaseTest):
    """
    Test file created with libxlsxwriter against a file created by Excel.

    """

    def test_chart_table01(self):
        self.run_exe_test('test_chart_table01')

    def test_chart_table02(self):
        self.run_exe_test('test_chart_table02')

    def test_chart_table03(self):
        self.ignore_elements = {'xl/charts/chart1.xml': ['<a:pPr']}
        self.run_exe_test('test_chart_table03')



###############################################################################
#
# Tests for libxlsxwriter.
#
# Copyright 2014-2022, John McNamara, jmcnamara@cpan.org
#

import base_test_class

class TestCompareXLSXFiles(base_test_class.XLSXBaseTest):
    """
    Test file created with libxlsxwriter against a file created by Excel.

    """

    def test_chart_gridlines01(self):
        self.run_exe_test('test_chart_gridlines01')

    def test_chart_gridlines02(self):
        self.run_exe_test('test_chart_gridlines02')

    # test_chart_gridlines03 is a stock chart.

    def test_chart_gridlines04(self):
        self.run_exe_test('test_chart_gridlines04')

    def test_chart_gridlines05(self):
        self.run_exe_test('test_chart_gridlines05')

    def test_chart_gridlines06(self):
        self.run_exe_test('test_chart_gridlines06')

    # test_chart_gridlines07 is a stock chart.

    def test_chart_gridlines08(self):
        self.run_exe_test('test_chart_gridlines08')

    def test_chart_gridlines09(self):
        self.run_exe_test('test_chart_gridlines09')



###############################################################################
#
# Tests for libxlsxwriter.
#
# Copyright 2014-2022, John McNamara, jmcnamara@cpan.org
#

import base_test_class

class TestCompareXLSXFiles(base_test_class.XLSXBaseTest):
    """
    Test file created with libxlsxwriter against a file created by Excel.

    """

    def test_button01(self):
        self.run_exe_test('test_button01')

    def test_button02(self):
        self.run_exe_test('test_button02')

    def test_button03(self):
        self.run_exe_test('test_button03')

    def test_button04(self):
        self.run_exe_test('test_button04')

    def test_button05(self):
        self.run_exe_test('test_button05')

    def test_button06(self):
        self.run_exe_test('test_button06', 'button05.xlsx')

    def test_button07(self):
        self.run_exe_test('test_button07', 'button07.xlsm')

    def test_button08(self):
        self.run_exe_test('test_button08')

    def test_button09(self):
        self.run_exe_test('test_button09')

    def test_button10(self):
        self.run_exe_test('test_button10')

    def test_button11(self):
        self.run_exe_test('test_button11')

    def test_button12(self):
        self.run_exe_test('test_button12')

    def test_button13(self):
        self.run_exe_test('test_button13', 'button07.xlsm')

    def test_button14(self):
        self.run_exe_test('test_button14', 'button07.xlsm')

    def test_button15(self):
        self.run_exe_test('test_button15')



###############################################################################
#
# Tests for libxlsxwriter.
#
# Copyright 2014-2022, John McNamara, jmcnamara@cpan.org
#

import base_test_class

class TestCompareXLSXFiles(base_test_class.XLSXBaseTest):
    """
    Test file created with libxlsxwriter against a file created by Excel.

    """

    def test_macro01(self):
        self.run_exe_test('test_macro01', 'macro01.xlsm')

    def test_macro02(self):
        self.run_exe_test('test_macro02', 'macro02.xlsm')

    def test_macro03(self):
        self.run_exe_test('test_macro03', 'macro03.xlsm')



###############################################################################
#
# Tests for libxlsxwriter.
#
# Copyright 2014-2022, John McNamara, jmcnamara@cpan.org
#

import base_test_class

class TestCompareXLSXFiles(base_test_class.XLSXBaseTest):
    """
    Test file created with libxlsxwriter against a file created by Excel.

    """

    def test_rich_string01(self):
        self.run_exe_test('test_rich_string01')

    def test_rich_string02(self):
        self.run_exe_test('test_rich_string02')

    def test_rich_string03(self):
        self.run_exe_test('test_rich_string03')

    def test_rich_string04(self):
        self.run_exe_test('test_rich_string04')

    def test_rich_string05(self):
        self.run_exe_test('test_rich_string05')

    def test_rich_string06(self):
        self.run_exe_test('test_rich_string06')

    def test_rich_string07(self):
        self.run_exe_test('test_rich_string07')

    def test_rich_string08(self):
        self.run_exe_test('test_rich_string08')

    def test_rich_string09(self):
        self.run_exe_test('test_rich_string09')

    def test_rich_string10(self):
        self.run_exe_test('test_rich_string10')

    def test_rich_string11(self):
        self.run_exe_test('test_rich_string11')

    def test_rich_string12(self):
        self.run_exe_test('test_rich_string12')



###############################################################################
#
# Tests for libxlsxwriter.
#
# Copyright 2014-2022, John McNamara, jmcnamara@cpan.org
#

import base_test_class

class TestCompareXLSXFiles(base_test_class.XLSXBaseTest):
    """
    Test file created with libxlsxwriter against a file created by Excel.

    """

    def test_row_colformat01(self):
        self.run_exe_test('test_row_col_format01')

    def test_row_colformat02(self):
        self.run_exe_test('test_row_col_format02')

    def test_row_colformat03(self):
        self.run_exe_test('test_row_col_format03')

    def test_row_colformat04(self):
        self.run_exe_test('test_row_col_format04')

    def test_row_colformat05(self):
        self.run_exe_test('test_row_col_format05')

    def test_row_colformat06(self):
        self.run_exe_test('test_row_col_format06')

    def test_row_colformat07(self):
        self.run_exe_test('test_row_col_format07')

    def test_row_colformat08(self):
        self.run_exe_test('test_row_col_format08')

    def test_row_colformat09(self):
        self.run_exe_test('test_row_col_format09')

    def test_row_colformat10(self):
        self.run_exe_test('test_row_col_format10')

    def test_row_colformat11(self):
        self.run_exe_test('test_row_col_format11')

    def test_row_colformat12(self):
        self.run_exe_test('test_row_col_format12')

    def test_row_colformat13(self):
        self.run_exe_test('test_row_col_format13')

    def test_row_colformat14(self):
        self.run_exe_test('test_row_col_format14')

    def test_row_colformat15(self):
        self.run_exe_test('test_row_col_format15')

    def test_row_colformat16(self):
        self.run_exe_test('test_row_col_format16')

    def test_row_colformat17(self):
        self.run_exe_test('test_row_col_format17')

    def test_row_colformat18(self):
        self.run_exe_test('test_row_col_format18')



###############################################################################
#
# Tests for libxlsxwriter.
#
# Copyright 2014-2022, John McNamara, jmcnamara@cpan.org
#

import base_test_class

class TestCompareXLSXFiles(base_test_class.XLSXBaseTest):
    """
    Test file created with libxlsxwriter against a file created by Excel.

    """

    def test_chart_font01(self):
        self.run_exe_test('test_chart_font01')

    def test_chart_font02(self):
        self.run_exe_test('test_chart_font02')

    def test_chart_font03(self):
        self.run_exe_test('test_chart_font03')

    def test_chart_font04(self):
        self.run_exe_test('test_chart_font04')

    def test_chart_font05(self):
        self.run_exe_test('test_chart_font05')

    def test_chart_font06(self):
        self.run_exe_test('test_chart_font06')

    def test_chart_font07(self):
        self.run_exe_test('test_chart_font07')

    def test_chart_font08(self):
        self.run_exe_test('test_chart_font08')

    def test_chart_font09(self):
        self.run_exe_test('test_chart_font09')



###############################################################################
#
# Tests for libxlsxwriter.
#
# Copyright 2014-2022, John McNamara, jmcnamara@cpan.org
#

import base_test_class

class TestCompareXLSXFiles(base_test_class.XLSXBaseTest):
    """
    Test file created with libxlsxwriter against a file created by Excel.

    """

    def test_dynamic_array01(self):
        self.run_exe_test('test_dynamic_array01')

    def test_dynamic_array02(self):
        self.run_exe_test('test_dynamic_array02')

    def test_dynamic_array03(self):
        self.run_exe_test('test_dynamic_array03')

    # Some variant of the default test case.
    def test_dynamic_array51(self):
        self.run_exe_test('test_dynamic_array51', 'dynamic_array01.xlsx')

    def test_dynamic_array52(self):
        self.run_exe_test('test_dynamic_array52', 'dynamic_array01.xlsx')

    def test_dynamic_array53(self):
        self.run_exe_test('test_dynamic_array53', 'dynamic_array01.xlsx')



###############################################################################
#
# Tests for libxlsxwriter.
#
# Copyright 2014-2022, John McNamara, jmcnamara@cpan.org
#

import base_test_class

class TestCompareXLSXFiles(base_test_class.XLSXBaseTest):
    """
    Test file created with libxlsxwriter against a file created by Excel.

    """

    def test_page_view01(self):
        self.run_exe_test('test_page_view01')

    def test_landscape01(self):
        self.run_exe_test('test_landscape01')

    def test_print_across01(self):
        self.ignore_elements = {'xl/worksheets/sheet1.xml': ['<pageMargins']}

        self.run_exe_test('test_print_across01')




###############################################################################
#
# Tests for libxlsxwriter.
#
# Copyright 2014-2022, John McNamara, jmcnamara@cpan.org
#

import base_test_class

class TestCompareXLSXFiles(base_test_class.XLSXBaseTest):
    """
    Test file created with libxlsxwriter against a file created by Excel.

    """

    def test_format01(self):
        self.run_exe_test('test_format01')

    def test_format02(self):
        self.run_exe_test('test_format02')

    def test_format06(self):
        self.run_exe_test('test_format06')

    def test_format07(self):
        self.run_exe_test('test_format07')

    def test_format08(self):
        self.run_exe_test('test_format08')

    def test_format09(self):
        self.run_exe_test('test_format09')

    def test_format10(self):
        self.run_exe_test('test_format10')

    def test_format12(self):
        self.run_exe_test('test_format12')

    def test_format15(self):
        self.run_exe_test('test_format15')

    def test_format16(self):
        self.run_exe_test('test_format16')

    def test_format17(self):
        self.run_exe_test('test_format17')

    def test_format50(self):
        self.run_exe_test('test_format50')

    def test_format51(self):
        self.run_exe_test('test_format51')

    def test_format52(self):
        self.run_exe_test('test_format52')



###############################################################################
#
# Tests for libxlsxwriter.
#
# Copyright 2014-2022, John McNamara, jmcnamara@cpan.org
#

import base_test_class

class TestCompareXLSXFiles(base_test_class.XLSXBaseTest):
    """
    Test file created with libxlsxwriter against a file created by Excel.

    """

    def test_chart_axis01(self):
        self.run_exe_test('test_chart_axis01')

    def test_chart_axis02(self):
        self.run_exe_test('test_chart_axis02')

    def test_chart_axis04(self):
        self.run_exe_test('test_chart_axis04')

    def test_chart_axis05(self):
        self.run_exe_test('test_chart_axis05')

    def test_chart_axis06(self):
        self.run_exe_test('test_chart_axis06')

    def test_chart_axis07(self):
        self.run_exe_test('test_chart_axis07')

    def test_chart_axis08(self):
        self.run_exe_test('test_chart_axis08')

    def test_chart_axis09(self):
        self.run_exe_test('test_chart_axis09')

    def test_chart_axis10(self):
        self.run_exe_test('test_chart_axis10')

    def test_chart_axis11(self):
        self.run_exe_test('test_chart_axis11')

    def test_chart_axis12(self):
        self.run_exe_test('test_chart_axis12')

    def test_chart_axis13(self):
        self.run_exe_test('test_chart_axis13')

    # Stock chart not supported yet.
    # def test_chart_axis14(self):
    #     self.run_exe_test('test_chart_axis14')

    def test_chart_axis15(self):
        self.run_exe_test('test_chart_axis15')

    def test_chart_axis17(self):
        self.run_exe_test('test_chart_axis17')

    def test_chart_axis18(self):
        self.run_exe_test('test_chart_axis18')

    def test_chart_axis19(self):
        self.run_exe_test('test_chart_axis19')

    def test_chart_axis20(self):
        self.run_exe_test('test_chart_axis20')

    def test_chart_axis21(self):
        self.run_exe_test('test_chart_axis21')

    def test_chart_axis22(self):
        self.run_exe_test('test_chart_axis22')

    def test_chart_axis23(self):
        self.run_exe_test('test_chart_axis23')

    def test_chart_axis24(self):
        self.run_exe_test('test_chart_axis24')

    def test_chart_axis25(self):
        self.run_exe_test('test_chart_axis25')

    def test_chart_axis26(self):
        self.run_exe_test('test_chart_axis26')

    def test_chart_axis27(self):
        self.run_exe_test('test_chart_axis27')

    def test_chart_axis28(self):
        self.run_exe_test('test_chart_axis28')

    def test_chart_axis29(self):
        self.run_exe_test('test_chart_axis29')

    def test_chart_axis30(self):
        self.run_exe_test('test_chart_axis30')

    def test_chart_axis31(self):
        self.run_exe_test('test_chart_axis31')

    def test_chart_axis32(self):
        self.run_exe_test('test_chart_axis32')

    def test_chart_axis33(self):
        self.run_exe_test('test_chart_axis33')

    def test_chart_axis34(self):
        self.run_exe_test('test_chart_axis34')

    def test_chart_axis35(self):
        self.run_exe_test('test_chart_axis35')

    def test_chart_axis36(self):
        self.run_exe_test('test_chart_axis36')

    def test_chart_axis37(self):
        self.run_exe_test('test_chart_axis37')

    def test_chart_axis38(self):
        self.run_exe_test('test_chart_axis38')

    def test_chart_axis39(self):
        self.run_exe_test('test_chart_axis39')

    def test_chart_axis40(self):
        self.run_exe_test('test_chart_axis40')

    def test_chart_axis41(self):
        self.run_exe_test('test_chart_axis41')

    def test_chart_axis42(self):
        self.run_exe_test('test_chart_axis42')

    def test_chart_axis43(self):
        self.run_exe_test('test_chart_axis43')

    def test_chart_axis44(self):
        self.run_exe_test('test_chart_axis44')

    def test_chart_axis45(self):
        self.run_exe_test('test_chart_axis45')

    def test_chart_axis46(self):
        self.run_exe_test('test_chart_axis46')

    def test_chart_axis47(self):
        self.run_exe_test('test_chart_axis47')

    def test_chart_axis48(self):
        self.run_exe_test('test_chart_axis48')



###############################################################################
#
# Tests for libxlsxwriter.
#
# Copyright 2014-2022, John McNamara, jmcnamara@cpan.org
#

import base_test_class

class TestCompareXLSXFiles(base_test_class.XLSXBaseTest):
    """
    Test file created with libxlsxwriter against a file created by Excel.

    """

    def test_autofilter00(self):
        self.run_exe_test('test_autofilter00')

    def test_autofilter01(self):
        self.run_exe_test('test_autofilter01')

    def test_autofilter02(self):
        self.run_exe_test('test_autofilter02')

    def test_autofilter03(self):
        self.run_exe_test('test_autofilter03')

    def test_autofilter04(self):
        self.run_exe_test('test_autofilter04')

    def test_autofilter05(self):
        self.run_exe_test('test_autofilter05')

    def test_autofilter06(self):
        self.run_exe_test('test_autofilter06')

    def test_autofilter07(self):
        self.run_exe_test('test_autofilter07')

    def test_autofilter08(self):
        self.run_exe_test('test_autofilter08')

    def test_autofilter09(self):
        self.run_exe_test('test_autofilter09')

    def test_autofilter10(self):
        self.run_exe_test('test_autofilter10')

    def test_autofilter11(self):
        self.run_exe_test('test_autofilter11')



###############################################################################
#
# Tests for libxlsxwriter.
#
# Copyright 2014-2022, John McNamara, jmcnamara@cpan.org
#

import base_test_class

class TestCompareXLSXFiles(base_test_class.XLSXBaseTest):
    """
    Test file created with libxlsxwriter against a file created by Excel.

    """

    def test_ignore_error01(self):
        self.run_exe_test('test_ignore_error01')

    def test_ignore_error02(self):
        self.run_exe_test('test_ignore_error02')

    def test_ignore_error03(self):
        self.run_exe_test('test_ignore_error03')

    def test_ignore_error04(self):
        self.run_exe_test('test_ignore_error04')

    def test_ignore_error05(self):
        self.ignore_files = ['xl/calcChain.xml',
                             '[Content_Types].xml',
                             'xl/_rels/workbook.xml.rels']
        self.ignore_elements = {'xl/worksheets/sheet1.xml': ['<c', '<v']}

        self.run_exe_test('test_ignore_error05')

    def test_ignore_error06(self):
        self.ignore_files = ['xl/calcChain.xml',
                             '[Content_Types].xml',
                             'xl/_rels/workbook.xml.rels']

        self.run_exe_test('test_ignore_error06')



###############################################################################
#
# Tests for libxlsxwriter.
#
# Copyright 2014-2022, John McNamara, jmcnamara@cpan.org
#

import base_test_class

class TestCompareXLSXFiles(base_test_class.XLSXBaseTest):
    """
    Test file created with libxlsxwriter against a file created by Excel.

    """

    def test_object_position01(self):
        self.run_exe_test('test_object_position01')

    def test_object_position02(self):
        self.run_exe_test('test_object_position02')

    def test_object_position03(self):
        self.run_exe_test('test_object_position03')

    def test_object_position04(self):
        self.run_exe_test('test_object_position04')

    def test_object_position06(self):
        self.run_exe_test('test_object_position06')

    def test_object_position07(self):
        self.run_exe_test('test_object_position07')

    def test_object_position08(self):
        self.ignore_files = ['xl/worksheets/sheet1.xml']
        self.run_exe_test('test_object_position08')

    def test_object_position09(self):
        self.ignore_files = ['xl/worksheets/sheet1.xml']
        self.run_exe_test('test_object_position09')

    def test_object_position10(self):
        self.run_exe_test('test_object_position10')

    def test_object_position12(self):
        self.run_exe_test('test_object_position12')

    def test_object_position13(self):
        self.run_exe_test('test_object_position13')

    def test_object_position14(self):
        self.run_exe_test('test_object_position14')

    def test_object_position15(self):
        self.run_exe_test('test_object_position15')

    def test_object_position16(self):
        self.run_exe_test('test_object_position16')

    def test_object_position17(self):
        self.run_exe_test('test_object_position17')

    def test_object_position18(self):
        self.run_exe_test('test_object_position18')

    def test_object_position19(self):
        self.run_exe_test('test_object_position19')

    def test_object_position20(self):
        self.run_exe_test('test_object_position20')

    # Test in-memory image handling.
    def test_object_position51(self):
        self.run_exe_test('test_object_position51', 'object_position01.xlsx')



###############################################################################
#
# Tests for libxlsxwriter.
#
# Copyright 2014-2022, John McNamara, jmcnamara@cpan.org
#

import base_test_class

class TestCompareXLSXFiles(base_test_class.XLSXBaseTest):
    """
    Test file created with libxlsxwriter against a file created by Excel.

    """

    def test_chart_data_labels01(self):
        self.run_exe_test('test_chart_data_labels01')

    def test_chart_data_labels02(self):
        self.run_exe_test('test_chart_data_labels02')

    def test_chart_data_labels03(self):
        self.run_exe_test('test_chart_data_labels03')

    def test_chart_data_labels04(self):
        self.run_exe_test('test_chart_data_labels04')

    def test_chart_data_labels05(self):
        self.run_exe_test('test_chart_data_labels05')

    def test_chart_data_labels06(self):
        self.run_exe_test('test_chart_data_labels06')

    def test_chart_data_labels07(self):
        self.run_exe_test('test_chart_data_labels07')

    def test_chart_data_labels08(self):
        self.run_exe_test('test_chart_data_labels08')

    def test_chart_data_labels09(self):
        self.run_exe_test('test_chart_data_labels09')

    def test_chart_data_labels10(self):
        self.run_exe_test('test_chart_data_labels10')

    def test_chart_data_labels11(self):
        self.run_exe_test('test_chart_data_labels11')

    def test_chart_data_labels12(self):
        self.run_exe_test('test_chart_data_labels12')

    def test_chart_data_labels13(self):
        self.run_exe_test('test_chart_data_labels13')

    def test_chart_data_labels14(self):
        self.run_exe_test('test_chart_data_labels14')

    def test_chart_data_labels15(self):
        self.run_exe_test('test_chart_data_labels15')

    def test_chart_data_labels16(self):
        self.run_exe_test('test_chart_data_labels16')

    # Stock chart.

    def test_chart_data_labels18(self):
        self.run_exe_test('test_chart_data_labels18')

    def test_chart_data_labels19(self):
        self.run_exe_test('test_chart_data_labels19')

    def test_chart_data_labels20(self):
        self.run_exe_test('test_chart_data_labels20')

    def test_chart_data_labels21(self):
        self.run_exe_test('test_chart_data_labels21')

    def test_chart_data_labels22(self):
        self.run_exe_test('test_chart_data_labels22')

    def test_chart_data_labels23(self):
        self.run_exe_test('test_chart_data_labels23')

    def test_chart_data_labels24(self):
        self.run_exe_test('test_chart_data_labels24')

    def test_chart_data_labels25(self):
        self.run_exe_test('test_chart_data_labels25')

    def test_chart_data_labels26(self):
        self.run_exe_test('test_chart_data_labels26')

    def test_chart_data_labels27(self):
        self.run_exe_test('test_chart_data_labels27')

    def test_chart_data_labels28(self):
        self.run_exe_test('test_chart_data_labels28')

    def test_chart_data_labels29(self):
        self.run_exe_test('test_chart_data_labels29')

    def test_chart_data_labels30(self):
        self.run_exe_test('test_chart_data_labels30')

    def test_chart_data_labels31(self):
        self.run_exe_test('test_chart_data_labels31')

    def test_chart_data_labels32(self):
        self.run_exe_test('test_chart_data_labels32')

    def test_chart_data_labels33(self):
        self.run_exe_test('test_chart_data_labels33')

    def test_chart_data_labels34(self):
        self.run_exe_test('test_chart_data_labels34')

    def test_chart_data_labels35(self):
        self.run_exe_test('test_chart_data_labels35')

    def test_chart_data_labels36(self):
        self.run_exe_test('test_chart_data_labels36')

    def test_chart_data_labels37(self):
        self.run_exe_test('test_chart_data_labels37')

    def test_chart_data_labels38(self):
        self.run_exe_test('test_chart_data_labels38')

    def test_chart_data_labels40(self):
        self.run_exe_test('test_chart_data_labels40')

    def test_chart_data_labels41(self):
        self.run_exe_test('test_chart_data_labels41')

    def test_chart_data_labels42(self):
        self.run_exe_test('test_chart_data_labels42')

    def test_chart_data_labels43(self):
        self.run_exe_test('test_chart_data_labels43')

    def test_chart_data_labels44(self):
        self.run_exe_test('test_chart_data_labels44')

    def test_chart_data_labels45(self):
        self.run_exe_test('test_chart_data_labels45')

    def test_chart_data_labels46(self):
        self.run_exe_test('test_chart_data_labels46')

    def test_chart_data_labels47(self):
        self.run_exe_test('test_chart_data_labels47')

    def test_chart_data_labels48(self):
        self.run_exe_test('test_chart_data_labels48')

    def test_chart_data_labels49(self):
        self.run_exe_test('test_chart_data_labels49')

    def test_chart_data_labels50(self):
        self.run_exe_test('test_chart_data_labels50')



###############################################################################
#
# Tests for libxlsxwriter.
#
# Copyright 2014-2022, John McNamara, jmcnamara@cpan.org
#

import os
import pytest
import base_test_class

class TestCompareXLSXFiles(base_test_class.XLSXBaseTest):
    """
    Test file created with libxlsxwriter against a file created by Excel.

    """

    def test_hyperlink01(self):
        self.run_exe_test('test_hyperlink01')

    def test_hyperlink02(self):
        self.run_exe_test('test_hyperlink02')

    def test_hyperlink03(self):
        self.run_exe_test('test_hyperlink03')

    def test_hyperlink04(self):
        self.run_exe_test('test_hyperlink04')

    def test_hyperlink05(self):
        self.run_exe_test('test_hyperlink05')

    def test_hyperlink06(self):
        self.run_exe_test('test_hyperlink06')

    def test_hyperlink07(self):
        self.run_exe_test('test_hyperlink07')

    def test_hyperlink08(self):
        self.run_exe_test('test_hyperlink08')

    def test_hyperlink09(self):
        self.run_exe_test('test_hyperlink09')

    def test_hyperlink10(self):
        self.run_exe_test('test_hyperlink10')

    def test_hyperlink11(self):
        self.run_exe_test('test_hyperlink11')

    def test_hyperlink12(self):
        self.run_exe_test('test_hyperlink12')

    def test_hyperlink13(self):
        # Ignore the count of duplicate strings.
        self.ignore_elements = {'xl/sharedStrings.xml': ['<sst']}
        self.run_exe_test('test_hyperlink13')

    def test_hyperlink14(self):
        # Ignore unused/overwritten strings.
        self.ignore_files = ['xl/sharedStrings.xml']
        self.run_exe_test('test_hyperlink14')

    def test_hyperlink15(self):
        self.run_exe_test('test_hyperlink15')

    def test_hyperlink16(self):
        self.run_exe_test('test_hyperlink16')

    def test_hyperlink17(self):
        self.run_exe_test('test_hyperlink17')

    def test_hyperlink18(self):
        self.run_exe_test('test_hyperlink18')

    # This test requires that we check if the cell that the hyperlink refers
    # to is a string. If it isn't we have to add a display attribute. However,
    # looking up the cell is currently too expensive.
    #
    # def test_hyperlink19(self):
    #     self.ignore_files = ['xl/calcChain.xml',
    #                          '[Content_Types].xml',
    #                          'xl/_rels/workbook.xml.rels']
    #     self.run_exe_test('test_hyperlink19')

    def test_hyperlink20(self):
        # Ignore custom colours.
        self.ignore_files = ['xl/styles.xml']
        self.run_exe_test('test_hyperlink20')

    def test_hyperlink21(self):
        self.run_exe_test('test_hyperlink21')

    def test_hyperlink22(self):
        self.run_exe_test('test_hyperlink22')

    def test_hyperlink23(self):
        self.run_exe_test('test_hyperlink23')

    def test_hyperlink24(self):
        self.run_exe_test('test_hyperlink24')

    def test_hyperlink25(self):
        self.run_exe_test('test_hyperlink25')

    def test_hyperlink26(self):
        self.run_exe_test('test_hyperlink26')

    def test_hyperlink27(self):
        self.run_exe_test('test_hyperlink27')

    def test_hyperlink28(self):
        self.run_exe_test('test_hyperlink28')

    def test_hyperlink29(self):
        self.run_exe_test('test_hyperlink29')

    def test_hyperlink30(self):
        # Ignore custom colors in styles.xml file.
        self.ignore_elements = {'xl/styles.xml': ['<color',
                                                  '<mruColors>',
                                                  '</mruColors>',
                                                  '</colors>']}
        self.run_exe_test('test_hyperlink30')

    def test_hyperlink31(self):
        self.run_exe_test('test_hyperlink31')

    # Copy of hyperlink28 with explicit formatting.
    def test_hyperlink78(self):
        self.run_exe_test('test_hyperlink78', 'hyperlink28.xlsx')

    def test_hyperlink32(self):
        self.run_exe_test('test_hyperlink32')

    def test_hyperlink33(self):
        self.run_exe_test('test_hyperlink33')

    def test_hyperlink34(self):
        self.run_exe_test('test_hyperlink34')

    def test_hyperlink35(self):
        self.run_exe_test('test_hyperlink35')

    def test_hyperlink36(self):
        self.run_exe_test('test_hyperlink36')

    # Skip 37 since it contains a textbox.

    def test_hyperlink38(self):
        self.run_exe_test('test_hyperlink38')

    def test_hyperlink39(self):
        self.run_exe_test('test_hyperlink39')

    def test_hyperlink40(self):
        self.run_exe_test('test_hyperlink40')

    def test_hyperlink41(self):
        self.run_exe_test('test_hyperlink41')

    def test_hyperlink42(self):
        self.run_exe_test('test_hyperlink42')

    def test_hyperlink43(self):
        self.run_exe_test('test_hyperlink43')

    def test_hyperlink44(self):
        self.run_exe_test('test_hyperlink44')

    def test_hyperlink45(self):
        self.run_exe_test('test_hyperlink45')

    def test_hyperlink46(self):
        self.run_exe_test('test_hyperlink46')

    def test_hyperlink47(self):
        self.run_exe_test('test_hyperlink47')

    @pytest.mark.skipif(os.environ.get('USE_NO_MD5'), reason="compiled without MD5 support")
    def test_hyperlink48(self):
        self.run_exe_test('test_hyperlink48')

    def test_hyperlink49(self):
        self.run_exe_test('test_hyperlink49')

    def test_hyperlink50(self):
        self.run_exe_test('test_hyperlink50')

    def test_hyperlink51(self):
        self.run_exe_test('test_hyperlink51')

    # Test in-memory image handling.
    def test_hyperlink81(self):
        self.run_exe_test('test_hyperlink81', 'hyperlink49.xlsx')

    def test_hyperlink81(self):
        self.run_exe_test('test_hyperlink82', 'hyperlink33.xlsx')



###############################################################################
#
# Tests for libxlsxwriter.
#
# Copyright 2014-2022, John McNamara, jmcnamara@cpan.org
#

import base_test_class

class TestCompareXLSXFiles(base_test_class.XLSXBaseTest):
    """
    Test file created with libxlsxwriter against a file created by Excel.

    """

    def test_outline01(self):
        self.ignore_files = ['xl/calcChain.xml',
                             '[Content_Types].xml',
                             'xl/_rels/workbook.xml.rels']
        self.run_exe_test('test_outline01')

    def test_outline02(self):
        self.ignore_files = ['xl/calcChain.xml',
                             '[Content_Types].xml',
                             'xl/_rels/workbook.xml.rels']
        self.run_exe_test('test_outline02')

    def test_outline03(self):
        self.ignore_files = ['xl/calcChain.xml',
                             '[Content_Types].xml',
                             'xl/_rels/workbook.xml.rels']
        self.run_exe_test('test_outline03')

    def test_outline04(self):
        self.ignore_files = ['xl/calcChain.xml',
                             '[Content_Types].xml',
                             'xl/_rels/workbook.xml.rels']
        self.run_exe_test('test_outline04')

    def test_outline05(self):
        self.ignore_files = ['xl/calcChain.xml',
                             '[Content_Types].xml',
                             'xl/_rels/workbook.xml.rels']
        self.run_exe_test('test_outline05')

    def test_outline06(self):
        self.ignore_files = ['xl/calcChain.xml',
                             '[Content_Types].xml',
                             'xl/_rels/workbook.xml.rels']
        self.run_exe_test('test_outline06')



###############################################################################
#
# Tests for libxlsxwriter.
#
# Copyright 2014-2022, John McNamara, jmcnamara@cpan.org
#

import base_test_class

# Tests for individual testcases that don't merit their own test suite.

class TestCompareXLSXFiles(base_test_class.XLSXBaseTest):
    """
    Test file created with libxlsxwriter against a file created by Excel.

    """

    # Tests for cases that don't deserve a full test_*.py of their own.

    def test_tab_color01(self):
        self.run_exe_test('test_tab_color01')

    def test_firstsheet01(self):
        self.run_exe_test('test_firstsheet01')

    def test_hide01(self):
        self.run_exe_test('test_hide01')

    def test_shared_strings01(self):
        self.run_exe_test('test_shared_strings01')

    def test_gh42_01(self):
        self.run_exe_test('test_gh42_01')

    def test_gh42_02(self):
        self.run_exe_test('test_gh42_02')

    def test_chart_legend01(self):
        self.run_exe_test('test_chart_legend01')

    def test_header04(self):
        self.ignore_elements = {'xl/worksheets/sheet1.xml': ['<pageSetup']}
        self.run_exe_test('test_header04')



###############################################################################
#
# Tests for libxlsxwriter.
#
# Copyright 2014-2022, John McNamara, jmcnamara@cpan.org
#

import base_test_class

class TestCompareXLSXFiles(base_test_class.XLSXBaseTest):
    """
    Test file created with libxlsxwriter against a file created by Excel.

    """

    def test_set_column01(self):
        self.run_exe_test('test_set_column01')

    def test_set_column02(self):
        self.run_exe_test('test_set_column02', 'set_column01.xlsx')

    def test_set_column03(self):
        self.run_exe_test('test_set_column03')

    def test_set_column04(self):
        self.run_exe_test('test_set_column04')

    def test_set_column05(self):
        self.run_exe_test('test_set_column05')

    def test_set_column06(self):
        # TODO. Fix span calculation for this condition.
        self.ignore_elements = {'xl/worksheets/sheet1.xml': ['<row r="13"']}
        self.run_exe_test('test_set_column06')

    def test_set_column07(self):
        self.run_exe_test('test_set_column07')

    def test_set_column08(self):
        # TODO. Fix span calculation for this condition.
        self.ignore_elements = {'xl/worksheets/sheet1.xml': ['<row r="13"']}
        self.run_exe_test('test_set_column08')

    def test_set_column09(self):
        self.run_exe_test('test_set_column09')

    def test_set_column10(self):
        self.run_exe_test('test_set_column10', 'set_column01.xlsx')

    def test_set_column11(self):
        # TODO. Fix span calculation for this condition.
        self.ignore_elements = {'xl/worksheets/sheet1.xml': ['<row r="13"']}
        self.run_exe_test('test_set_column11', 'set_column06.xlsx')



###############################################################################
#
# Tests for libxlsxwriter.
#
# Copyright 2014-2022, John McNamara, jmcnamara@cpan.org
#

import base_test_class

class TestCompareXLSXFiles(base_test_class.XLSXBaseTest):
    """
    Test file created with libxlsxwriter against a file created by Excel.

    """

    def test_comment01(self):
        self.run_exe_test('test_comment01')

    def test_comment02(self):
        self.run_exe_test('test_comment02')

    def test_comment03(self):
        self.run_exe_test('test_comment03')

    def test_comment04(self):
        self.run_exe_test('test_comment04')

    def test_comment05(self):
        self.run_exe_test('test_comment05')

    def test_comment06(self):
        self.run_exe_test('test_comment06')

    def test_comment07(self):
        self.run_exe_test('test_comment07')

    def test_comment08(self):
        self.run_exe_test('test_comment08')

    def test_comment09(self):
        self.run_exe_test('test_comment09')

    def test_comment10(self):
        self.run_exe_test('test_comment10')

    def test_comment11(self):
        self.run_exe_test('test_comment11')

    def test_comment12(self):
        self.run_exe_test('test_comment12')

    def test_comment13(self):
        self.ignore_files = ['xl/styles.xml']
        self.run_exe_test('test_comment13')

    def test_comment14(self):
        self.run_exe_test('test_comment14')

    def test_comment15(self):
        self.run_exe_test('test_comment15')

    def test_comment16(self):
        self.run_exe_test('test_comment16')

    # Memory leak test.
    def test_comment56(self):
        self.run_exe_test('test_comment56', 'comment16.xlsx')



###############################################################################
#
# Tests for libxlsxwriter.
#
# Copyright 2014-2022, John McNamara, jmcnamara@cpan.org
#

import base_test_class

class TestCompareXLSXFiles(base_test_class.XLSXBaseTest):
    """
    Test file created with libxlsxwriter against a file created by Excel.

    """

    def test_chart_column01(self):
        self.run_exe_test('test_chart_column01')

    def test_chart_column02(self):
        self.run_exe_test('test_chart_column02')

    def test_chart_column03(self):
        self.run_exe_test('test_chart_column03')

    def test_chart_column05(self):
        self.run_exe_test('test_chart_column05')

    def test_chart_column06(self):
        self.run_exe_test('test_chart_column06')

    def test_chart_column07(self):
        self.run_exe_test('test_chart_column07')

    def test_chart_column08(self):
        self.run_exe_test('test_chart_column08')

    def test_chart_column09(self):
        self.run_exe_test('test_chart_column09')

    def test_chart_column10(self):
        self.run_exe_test('test_chart_column10')

    def test_chart_column11(self):
        self.run_exe_test('test_chart_column11')

    def test_chart_column12(self):
        self.run_exe_test('test_chart_column12')

    def test_chart_column13(self):
        self.run_exe_test('test_chart_column13')



###############################################################################
#
# Tests for libxlsxwriter.
#
# Copyright 2014-2022, John McNamara, jmcnamara@cpan.org
#

import base_test_class

class TestCompareXLSXFiles(base_test_class.XLSXBaseTest):
    """
    Test file created with libxlsxwriter against a file created by Excel.

    """

    def test_cond_format01(self):
        self.run_exe_test('test_cond_format01')

    def test_cond_format02(self):
        self.run_exe_test('test_cond_format02')

    def test_cond_format03(self):
        self.run_exe_test('test_cond_format03')

    def test_cond_format04(self):
        self.run_exe_test('test_cond_format04')

    def test_cond_format05(self):
        self.run_exe_test('test_cond_format05')

    def test_cond_format06(self):
        self.run_exe_test('test_cond_format06')

    def test_cond_format07(self):
        self.run_exe_test('test_cond_format07')

    def test_cond_format08(self):
        self.run_exe_test('test_cond_format08')

    def test_cond_format09(self):
        self.run_exe_test('test_cond_format09', 'cond_format08.xlsx')

    def test_cond_format10(self):
        self.run_exe_test('test_cond_format10')

    def test_cond_format11(self):
        self.run_exe_test('test_cond_format11')

    def test_cond_format12(self):
        self.run_exe_test('test_cond_format12')

    def test_cond_format13(self):
        self.run_exe_test('test_cond_format13', 'cond_format04.xlsx')

    def test_cond_format14(self):
        self.run_exe_test('test_cond_format14')

    def test_cond_format15(self):
        self.run_exe_test('test_cond_format15')

    def test_cond_format16(self):
        self.run_exe_test('test_cond_format16')

    def test_cond_format17(self):
        self.run_exe_test('test_cond_format17')



###############################################################################
#
# Tests for libxlsxwriter.
#
# Copyright 2014-2022, John McNamara, jmcnamara@cpan.org
#

import base_test_class

class TestCompareXLSXFiles(base_test_class.XLSXBaseTest):
    """
    Test file created with libxlsxwriter against a file created by Excel.

    """

    def test_chart_points01(self):
        self.run_exe_test('test_chart_points01')

    def test_chart_points02(self):
        self.run_exe_test('test_chart_points02')

    def test_chart_points03(self):
        # Ignore custom colors in styles.xml file.
        self.ignore_files = ['xl/styles.xml']
        self.run_exe_test('test_chart_points03')

    def test_chart_points04(self):
        self.run_exe_test('test_chart_points04')

    def test_chart_points05(self):
        self.run_exe_test('test_chart_points05')

    def test_chart_points06(self):
        self.run_exe_test('test_chart_points06')



###############################################################################
#
# Tests for libxlsxwriter.
#
# Copyright 2014-2022, John McNamara, jmcnamara@cpan.org
#

import base_test_class

class TestCompareXLSXFiles(base_test_class.XLSXBaseTest):
    """
    Test file created with libxlsxwriter against a file created by Excel.

    """

    def test_chart_legend01(self):
        self.run_exe_test('test_chart_legend01')

    # def test_chart_legend02(self):
    #     self.run_exe_test('test_chart_legend02')
    # This is just a duplicate of test_chart_legend01.

    def test_chart_legend03(self):
        self.run_exe_test('test_chart_legend03')

    def test_chart_legend04(self):
        self.run_exe_test('test_chart_legend04')

   



###############################################################################
#
# Tests for libxlsxwriter.
#
# Copyright 2014-2022, John McNamara, jmcnamara@cpan.org
#
import os
import pytest
import base_test_class

class TestCompareXLSXFiles(base_test_class.XLSXBaseTest):
    """
    Test file created with libxlsxwriter against a file created by Excel.

    """

    def test_background01(self):
        self.run_exe_test('test_background01')

    def test_background02(self):
        self.run_exe_test('test_background02')

    def test_background03(self):
        self.run_exe_test('test_background03')

    @pytest.mark.skipif(os.environ.get('USE_NO_MD5'), reason="compiled without MD5 support")
    def test_background04(self):
        self.run_exe_test('test_background04')

    def test_background05(self):
        self.run_exe_test('test_background05')

    def test_background06(self):
        self.ignore_elements = {'xl/worksheets/sheet1.xml': ['<pageSetup']}
        self.run_exe_test('test_background06')

    def test_background07(self):
        self.ignore_elements = {'xl/worksheets/sheet1.xml': ['<pageSetup']}
        self.run_exe_test('test_background07')

    # Same as background02 except with an image buffer.
    def test_background52(self):
        self.run_exe_test('test_background52', 'background02.xlsx')

